@@ -21,6 +21,7 @@ def _init():
     # Main entrypoint and initialize the cmd method
     # set_defaults specifies a method that is called if that parser is used
     parser = argparse.ArgumentParser(description="Autonomy Toolkit Command Line Interface")
+    parser.add_argument('--version', action="store_true",  help='Level of verbosity', default=False)
     parser.add_argument('-v', '--verbose', dest='verbosity', action='count', help='Level of verbosity', default=0)
     parser.add_argument('--dry-run', action="store_true", help="Test run that will print out the commands it would run but not actually run them")
     parser.set_defaults(cmd=lambda x: x)
@@ -38,6 +39,13 @@ def _main():
 
     # Parse the arguments and update logging
     known_args, unknown_args = parser.parse_known_args()
+
+    # Return version if desired and exit
+    if known_args.version:
+        from autonomy_toolkit import __version__
+        print(__version__)
+        return
+
     set_verbosity(known_args.verbosity)
 
     # Calls the cmd for the used subparser
